# electric

It is an electric calculation package
[Documment](https://nishizumi-lab.github.io/libs/flutter/01_package/electric/docs/html/index.html)


# 参考資料


## 電気主任技術者関連

[地上設置型太陽光発電システムの設計ガイドライン2019年版](https://www.nedo.go.jp/activities/ZZJP2_100060.html#guideline)

[経済産業省 法令｜電力の安全](https://www.meti.go.jp/policy/safety_security/industrial_safety/law/index.html)

[電気事業法　告示・内規等](https://www.meti.go.jp/policy/safety_security/industrial_safety/law/denjikokuji.html)

[JIS C 8955（太陽電池アレイ用支持物の設計用荷重算出方法）の改定内容](https://www.safety-chugoku.meti.go.jp/denki/hatsuden/taiyoukou/file/seminarshiryou2.pdf)

# Sample code

```
    // @param Zb 地表面粗度区分で定まる値(JIS C 8955 表) 5
    // @param Zg 地表面粗度区分で定まる値(JIS C 8955 表) 450
    // @param alpha 地表面粗度区分で定まる値(JIS C 8955 表) 0.20
    // @param H アレイ面の平均地上高(m)(アレイの最大高さと最小高さの中間) 1.789
    // @retval 平均風速の高さ方向の分布を表す係数Er
    print(wp.calcEr(5, 450, 0.20, 1.789)); // 0.6911947320312629

    // @brief 平均風速の高さ方向の分布を表す係数Er、ガスト影響係数Gfから環境係数Eを計算します。
    // @param Er 平均風速の高さ方向の分布を表す係数(calcErで計算) 0.691
    // @param Gf ガスト影響係数（※突風の影響を示す）(JIS C 8955 表) 2.5
    // @retval 環境係数E
    print(wp.calcE(0.691, 2.5)); // 1.1937024999999999

    // @brief 設計用基準風速V0、環境係数E、用途係数Iwから設計用速度圧qを計算します。
    // @param V0 設計用基準風速V0(m/s)(JIS C 8955 表より地域で決まる) 34
    // @param E 環境係数E(calcEで計算) 1.194
    // @param Iw 用途係数Iw(JIS C 8955 表より利用用途で決まる) 1.0
    // @retval 設計用速度圧q 828.1583999999998
    print(wp.calcQp(34, 1.194, 1.0)); // 828.1583999999998

    // @brief 風力係数C、設計用速度圧q、受風面積Aから風圧荷重を計算します。
    // @param C アレイ面，支持物構成材の風力係数(別途計算) 1.25
    // @param q 設計用速度圧q(calcQpで計算) 828
    // @param A アレイ面の受風面積，支持物構成材の鉛直投影面積A（m2）(架台とアレイの寸法から別途計算) 1.0
    // @retval アレイ，支持物構成材に作用する風圧荷重W（N） 1035.0
    print(wp.calcW(828, 1.25, 1.0)); // 1035.0
```


