import 'package:flutter_test/flutter_test.dart';
import 'package:electric/taigi/taigi4_wind_pressure.dart';

void main() {
  test('adds one to input values', () {
    final wp = WindPressure();



    // @param Zb 地表面粗度区分で定まる値(JIS C 8955 表) 5
    // @param Zg 地表面粗度区分で定まる値(JIS C 8955 表) 450
    // @param alpha 地表面粗度区分で定まる値(JIS C 8955 表) 0.20
    // @param H アレイ面の平均地上高(m)(アレイの最大高さと最小高さの中間) 1.789
    // @retval 平均風速の高さ方向の分布を表す係数Er
    print(wp.calcEr(5, 450, 0.20, 1.789)); // 0.6911947320312629

    // @brief 平均風速の高さ方向の分布を表す係数Er、ガスト影響係数Gfから環境係数Eを計算します。
    // @param Er 平均風速の高さ方向の分布を表す係数(calcErで計算) 0.691
    // @param Gf ガスト影響係数（※突風の影響を示す）(JIS C 8955 表) 2.5
    // @retval 環境係数E
    print(wp.calcE(0.691, 2.5)); // 1.1937024999999999

    // @brief 設計用基準風速V0、環境係数E、用途係数Iwから設計用速度圧qを計算します。
    // @param V0 設計用基準風速V0(m/s)(JIS C 8955 表より地域で決まる) 34
    // @param E 環境係数E(calcEで計算) 1.194
    // @param Iw 用途係数Iw(JIS C 8955 表より利用用途で決まる) 1.0
    // @retval 設計用速度圧q 828.1583999999998
    print(wp.calcQp(34, 1.194, 1.0)); // 828.1583999999998

    // @brief 風力係数C、設計用速度圧q、受風面積Aから風圧荷重を計算します。
    // @param C アレイ面，支持物構成材の風力係数(別途計算) 1.25
    // @param q 設計用速度圧q(calcQpで計算) 828
    // @param A アレイ面の受風面積，支持物構成材の鉛直投影面積A（m2）(架台とアレイの寸法から別途計算) 1.0
    // @retval アレイ，支持物構成材に作用する風圧荷重W（N） 1035.0
    print(wp.calcW(828, 1.25, 1.0)); // 1035.0

  });
}
